[nautilus-actions] Use top_srcdir instead of srcdir



commit ac4361edadcc724fa638214bac25829aa794dbae
Author: Pierre Wieser <pwieser trychlos org>
Date:   Mon Feb 20 06:17:23 2012 +0100

    Use top_srcdir instead of srcdir

 ChangeLog        |    5 +++++
 run-autogen.sh   |   14 +++++++-------
 run-distcheck.sh |   16 ++++++++--------
 3 files changed, 20 insertions(+), 15 deletions(-)
---
diff --git a/ChangeLog b/ChangeLog
index 4dd5b99..c6f972d 100644
--- a/ChangeLog
+++ b/ChangeLog
@@ -1,3 +1,8 @@
+2012-02-20 Pierre Wieser <pwieser trychlos org>
+
+	* run-autogen.sh:
+	* run-distcheck.sh: Replace srcdir with top_srcdir.
+
 2012-02-17 Pierre Wieser <pwieser trychlos org>
 
 	* src/core/na-ioption.c (get_ioption_data):
diff --git a/run-distcheck.sh b/run-distcheck.sh
index 38ec5b9..20be06e 100755
--- a/run-distcheck.sh
+++ b/run-distcheck.sh
@@ -1,22 +1,22 @@
 #!/bin/sh
 
-srcdir=$(cd ${0%/*}; pwd)
-builddir="_build"
+top_srcdir=$(cd ${0%/*}; pwd)
+builddir="${top_srcdir}/_build"
 
 # a nautilus-actions-x.y may remain after an aborted make distcheck
 # such a directory breaks gnome-autogen.sh generation
 # so clean it here
-for d in $(find ${srcdir} -maxdepth 2 -type d -name 'nautilus-actions-*'); do
+for d in $(find ${top_srcdir} -maxdepth 2 -type d -name 'nautilus-actions-*'); do
 	chmod -R u+w $d
 	rm -fr $d
 done
 
 rm -fr ${builddir}
 rm -fr _install
-find ${srcdir}/docs/nact -type f -name '*.html' -o -name '*.pdf' | xargs rm -f
-find ${srcdir}/docs/nact \( -type d -o -type l \) -name 'stylesheet-images' -o -name 'admon' | xargs rm -fr
+find ${top_srcdir}/docs/nact -type f -name '*.html' -o -name '*.pdf' | xargs rm -f
+find ${top_srcdir}/docs/nact \( -type d -o -type l \) -name 'stylesheet-images' -o -name 'admon' | xargs rm -fr
 
-target=doc ${srcdir}/run-autogen.sh &&
-	${srcdir}/tools/check-po.sh -nodummy &&
-	${srcdir}/tools/check-headers.sh -nodummy -builddir=${builddir} &&
+target=doc ${top_srcdir}/run-autogen.sh &&
+	${top_srcdir}/tools/check-po.sh -nodummy &&
+	${top_srcdir}/tools/check-headers.sh -nodummy -builddir=${builddir} &&
 	make -C ${builddir} distcheck



[Date Prev][Date Next]   [Thread Prev][Thread Next]   [Thread Index] [Date Index] [Author Index]
diff --git a/run-autogen.sh b/run-autogen.sh
index 63b10ea..6208c97 100755
--- a/run-autogen.sh
+++ b/run-autogen.sh
@@ -11,12 +11,12 @@
 #    current working directory
 
 target=${target:-normal}
-srcdir=$(cd ${0%/*}; pwd)
+top_srcdir=$(cd ${0%/*}; pwd)
 
 # a nautilus-actions-x.y may remain after an aborted make distcheck
 # such a directory breaks gnome-autogen.sh generation
 # so clean it here
-for d in $(find ${srcdir} -maxdepth 2 -type d -name 'nautilus-actions-*'); do
+for d in $(find ${top_srcdir} -maxdepth 2 -type d -name 'nautilus-actions-*'); do
 	chmod -R u+w $d
 	rm -fr $d
 done
@@ -59,18 +59,18 @@ fi
 #			--disable-schemas-install \
 #			$*
 
-NOCONFIGURE=1 ${srcdir}/autogen.sh
+NOCONFIGURE=1 ${top_srcdir}/autogen.sh
 
-runconf=${srcdir}/run-configure.sh
+runconf=${top_srcdir}/run-configure.sh
 echo "
 Generating ${runconf}"
 
 cat <<EOF >${runconf}
 #!/bin/sh
 
 # srcdir here is the root of the source directory
 target=\${target:-normal}
-srcdir=\$(cd \${0%/*}; pwd)
+top_srcdir=\$(cd \${0%/*}; pwd)
 
 # heredir is the root of the _build/_install directories
 heredir=\$(pwd)
@@ -78,7 +78,7 @@ heredir=\$(pwd)
 mkdir -p \${heredir}/_build
 cd \${heredir}/_build
 
-conf_cmd="\${srcdir}/configure"
+conf_cmd="\${top_srcdir}/configure"
 conf_args="${conf_args}"
 conf_args="\${conf_args} --prefix=\${heredir}/_install"
 conf_args="\${conf_args} --sysconfdir=/etc"
@@ -59,18 +59,18 @@ fi
 #!/bin/sh
 
-# srcdir here is the root of the source directory
+# top_srcdir here is the root of the source directory
 target=\${target:-normal}